package com.ruoyi.invest.mapper;

import java.util.List;
import com.ruoyi.invest.domain.TProjectInvestigatePerson;
import org.apache.ibatis.annotations.Param;

/**
 * 尽调人员关联表Mapper接口
 * 
 * @author zjc
 * @date 2024-03-13
 */
public interface TProjectInvestigatePersonMapper 
{
    /**
     * 查询尽调人员关联表
     * 
     * @param id 尽调人员关联表主键
     * @return 尽调人员关联表
     */
    public TProjectInvestigatePerson selectTProjectInvestigatePersonById(String id);

    /**
     * 查询尽调人员关联表列表
     * 
     * @param tProjectInvestigatePerson 尽调人员关联表
     * @return 尽调人员关联表集合
     */
    public List<TProjectInvestigatePerson> selectTProjectInvestigatePersonList(TProjectInvestigatePerson tProjectInvestigatePerson);

    /**
     * 新增尽调人员关联表
     * 
     * @param tProjectInvestigatePerson 尽调人员关联表
     * @return 结果
     */
    public int insertTProjectInvestigatePerson(TProjectInvestigatePerson tProjectInvestigatePerson);

    /**
     * 修改尽调人员关联表
     * 
     * @param tProjectInvestigatePerson 尽调人员关联表
     * @return 结果
     */
    public int updateTProjectInvestigatePerson(TProjectInvestigatePerson tProjectInvestigatePerson);

    /**
     * 删除尽调人员关联表
     * 
     * @param id 尽调人员关联表主键
     * @return 结果
     */
    public int deleteTProjectInvestigatePersonById(String id);

    /**
     * 批量删除尽调人员关联表
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTProjectInvestigatePersonByIds(String[] ids);

    /**
     * 根据尽调申请ID获取尽调人员关联表详细信息
     *
     * @param projectInvestigateId
     * @param userId
     * @return
     */
    TProjectInvestigatePerson selectByProjectInvestigateId(@Param("projectInvestigateId")String projectInvestigateId, @Param("userId")Long userId);

    /**
     * 根据尽调申请ID获取尽调人员关联表集合
     * @param projectInvestigateId
     * @return
     */
    List<TProjectInvestigatePerson> selectProjectInvestigateIdList(@Param("projectInvestigateId")String projectInvestigateId);
}
